@@ -46,7 +46,7 @@ def get_invalid_names() -> List[str]:
                       'datetime', 'random', 'numpy', 'json', 'spade', 'copy', 'uuid',
                       'get_json_from_spade_message', 'get_spade_message', 'logger',
                       'any', 'sys', 'limit_number', 'int', 'BackupBehaviour', 
-                      'backup_url', 'backup_period', 'backup_delay' ]
+                      'backup_url', 'backup_period', 'backup_delay', 'setup' ]
     invalid_names.extend(keyword.kwlist)
     return invalid_names
 
